Insecure communication
Please set up SSL as soon as possible!
ajenti
Log out

# Crashed

    Blah blah

Submit this report to Github
or Launchpad
Submit bug
Reload page
Continue

# Access denied

Reload page Continue

# Reconnecting

Feedback & help

Your Ajenti instance is missing compiled CSS files.

If you are running Ajenti in a development environment, run `make run`.

If not, your installation package was probably broken.